Learn R Programming

stoRy (version 0.1.1)

story_ids_by_theme: Story theme summary

Description

A table in which each theme is summarised accoring to the stories in which it is featured.

Arguments

Format

Data frame